@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Muldis::D; # package
-    use version 0.74; our $VERSION = qv('0.67.0');
+    use version 0.74; our $VERSION = qv('0.68.0');
     # Note that Perl code only exists at all in this file in order to help
     # the CPAN indexer handle the distribution properly.
 } # package Muldis::D
@@ -29,7 +29,7 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Muldis::D version 0.67.0.
+This document is Muldis::D version 0.68.0.
 
 =head1 PREFACE
 
@@ -37,9 +37,9 @@ This is the root document of the Muldis D language specification; the
 documents that comprise the remaining parts of the specification, in their
 suggested reading order (but that all follow the root), are:
 L<Muldis::D::Basics>, L<Muldis::D::Core> (which has its own tree of parts
-to follow), L<Muldis::D::Dialect::PTMD_Tiny>,
-L<Muldis::D::Dialect::HDMD_Perl6_Tiny>,
-L<Muldis::D::Dialect::HDMD_Perl5_Tiny>, L<Muldis::D::Conventions>,
+to follow), L<Muldis::D::Dialect::PTMD_STD>,
+L<Muldis::D::Dialect::HDMD_Perl6_STD>,
+L<Muldis::D::Dialect::HDMD_Perl5_STD>, L<Muldis::D::Conventions>,
 L<Muldis::D::Ext::Ordered>, L<Muldis::D::Ext::Integer>,
 L<Muldis::D::Ext::Blob>, L<Muldis::D::Ext::Text>,
 L<Muldis::D::Ext::Rational>, L<Muldis::D::Ext::QTuple>,
@@ -59,9 +59,9 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<Muldis_D:"http://muldis.com":"0.67.0">.  It is the official/original (not
+C<Muldis_D:"http://muldis.com":"0.68.0">.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Darren Duncan (C<http://muldis.com>), version C<0.67.0> (this number
+Darren Duncan (C<http://muldis.com>), version C<0.68.0> (this number
 matches the VERSION pod in this file).  This multi-part document is named
 and organized with the expectation that many dialects, extensions, and core
 versions of it will exist over time, some of those under the original
@@ -263,8 +263,8 @@ code's behavior.
 
 See the following parts of the current multi-document for descriptions of
 bundled dialects (names subject to change):
-L<Muldis::D::Dialect::PTMD_Tiny>, L<Muldis::D::Dialect::HDMD_Perl6_Tiny>,
-L<Muldis::D::Dialect::HDMD_Perl5_Tiny>.
+L<Muldis::D::Dialect::PTMD_STD>, L<Muldis::D::Dialect::HDMD_Perl6_STD>,
+L<Muldis::D::Dialect::HDMD_Perl5_STD>.
 
 =head2 Extensions
 
